@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: npdjvu.cpp,v 1.8 2009/03/06 21:32:40 leonb Exp $
+// $Id: npdjvu.cpp,v 1.10 2009/10/11 22:37:45 leonb Exp $
 
 #include "config.h"
 #include <locale.h>
@@ -166,6 +166,11 @@ setupApplication(QtNPInstance *instance)
   QApplication::setOrganizationDomain(DJVIEW_DOMAIN);
   QApplication::setApplicationName(DJVIEW_APP);
   qInstallMsgHandler(qtMessageHandler);
+  // mac
+#ifdef Q_WS_MAC
+  extern void qt_mac_set_native_menubar(bool);
+  qt_mac_set_native_menubar(false);
+#endif
   // application
   qtns_initialize(instance);
   if (! djvuContext)
@@ -173,6 +178,12 @@ setupApplication(QtNPInstance *instance)
   theApp = (QApplication*)QCoreApplication::instance();
 #ifdef Q_WS_X11
   theApp->setEventFilter(x11EventFilter);
+#endif
+#ifdef LC_NUMERIC
+  //   This is needed in the pdf export code in order to make
+  //   sure numbers are represented properly. But is it really
+  //   good to change the global state of the browser?
+  ::setlocale(LC_NUMERIC, "C");
 #endif
   // translators
   QTranslator *qtTrans = new QTranslator(theApp);
@@ -671,7 +682,8 @@ NPP_SetWindow(NPP npp, NPWindow* window)
       clipRect = QRect(window->clipRect.left, window->clipRect.top,
                        window->clipRect.right - window->clipRect.left,
                        window->clipRect.bottom - window->clipRect.top);
-      instance->geometry = QRect(window->x, window->y, window->width, window->height);
+      instance->geometry = QRect(window->x, window->y, 
+                                 window->width, window->height);
     }
   // take a shortcut if all that was changed is the geometry
   if (instance->djview && window && 
