@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: djview.cpp,v 1.64 2009/02/22 16:50:54 leonb Exp $
+// $Id: djview.cpp,v 1.71 2010/02/07 18:16:14 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -109,17 +109,36 @@ addDirectory(QStringList &dirs, QString path)
 
 
 QDjViewApplication::QDjViewApplication(int &argc, char **argv)
-  : QApplication(argc, argv), context(argv[0])
+  : QApplication(argc, argv), 
+    context(argv[0])
 {
   // Message handler
   qInstallMsgHandler(qtMessageHandler);
-
-
+  
+  // Locale should not mess with printf
+  // We do this again because old libdjvulibre
+  // did not correctly set LC_NUMERIC.
+#ifdef LC_ALL
+  ::setlocale(LC_ALL, "");
+# ifdef LC_NUMERIC
+  ::setlocale(LC_NUMERIC, "C");
+# endif
+#endif
+  
+  // Mac/Cocoa bug workaround
+#if defined(Q_WS_MAC) && defined(QT_MAC_USE_COCOA) && QT_VERSION<0x40503
+  extern void qt_mac_set_native_menubar(bool);
+  qt_mac_set_native_menubar(false);
+#endif
+  
   // Translators
   QTranslator *qtTrans = new QTranslator(this);
   QTranslator *djviewTrans = new QTranslator(this);
   // - determine preferred languages
   QStringList langs; 
+  QString langOverride = QSettings().value("language").toString();
+  if (! langOverride.isEmpty())
+    langs += langOverride;
   QString varLanguage = ::getenv("LANGUAGE");
   if (varLanguage.size())
     langs += varLanguage.toLower().split(":", QString::SkipEmptyParts);
@@ -315,12 +334,6 @@ usage()
 int 
 main(int argc, char *argv[])
 {
-  // Locale
-#ifdef LC_ALL
-  ::setlocale(LC_ALL, "");
-  ::setlocale(LC_NUMERIC, "C");
-#endif
-
   // Application data
   QApplication::setOrganizationName(DJVIEW_ORG);
   QApplication::setOrganizationDomain(DJVIEW_DOMAIN);
@@ -423,7 +436,7 @@ main(int argc, char *argv[])
           exit(10);
         }
     }
-
+  
   // Process events
   main->show();
   return app.exec();
