@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewdialogs.cpp,v 1.82 2009/02/22 16:50:54 leonb Exp $
+// $Id: qdjviewdialogs.cpp,v 1.84 2010/07/25 18:00:30 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -599,11 +599,13 @@ QDjViewMetaDialog::QDjViewMetaDialog(QDjView *parent)
   d->ui.docTable->setHorizontalHeaderLabels(labels);
   d->ui.docTable->horizontalHeader()->setHighlightSections(false);
   d->ui.docTable->horizontalHeader()->setStretchLastSection(true);
+  d->ui.docTable->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
   d->ui.docTable->verticalHeader()->hide();
   d->ui.pageTable->setColumnCount(2);
   d->ui.pageTable->setHorizontalHeaderLabels(labels);
   d->ui.pageTable->horizontalHeader()->setHighlightSections(false);
   d->ui.pageTable->horizontalHeader()->setStretchLastSection(true);
+  d->ui.pageTable->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
   d->ui.pageTable->verticalHeader()->hide();
   d->ui.pageCombo->setEnabled(false);
   d->ui.jumpButton->setEnabled(false);
@@ -706,10 +708,10 @@ metadataFill(QTableWidget *table, QMap<QString,QString> m)
       table->setItem(j, 0, kitem);
       table->setItem(j, 1, vitem);
     }
-  table->resizeColumnsToContents();
-  table->resizeRowsToContents();
+  table->resizeColumnToContents(0);
 }
 
+
 void 
 QDjViewMetaDialog::refresh()
 {
@@ -1062,8 +1064,8 @@ QDjViewSaveDialog::browse()
   if (! fname.isEmpty())
     {
       QFileInfo finfo(fname);
-      if (finfo.completeSuffix().isEmpty() && !suffix.isEmpty())
-        fname = QFileInfo(finfo.dir(), finfo.baseName() 
+      if (finfo.suffix().isEmpty() && !suffix.isEmpty())
+        fname = QFileInfo(finfo.dir(), finfo.completeBaseName() 
                           + "." + suffix).filePath();
       d->ui.fileNameEdit->setText(fname);
     }
@@ -1243,8 +1245,8 @@ QDjViewExportDialog::refresh()
             {
               QString suffix = info[1];
               QFileInfo finfo(fname);
-              if (!finfo.completeSuffix().isEmpty() && !suffix.isEmpty())
-                fname = QFileInfo(finfo.dir(), finfo.baseName() 
+              if (!finfo.suffix().isEmpty() && !suffix.isEmpty())
+                fname = QFileInfo(finfo.dir(), finfo.completeBaseName() 
                                   + "." + suffix).filePath();
               d->ui.fileNameEdit->setText(fname);
             }
@@ -1411,8 +1413,8 @@ QDjViewExportDialog::browse()
   if (! fname.isEmpty())
     {
       QFileInfo finfo(fname);
-      if (finfo.completeSuffix().isEmpty() && !suffix.isEmpty())
-        fname = QFileInfo(finfo.dir(), finfo.baseName() 
+      if (finfo.suffix().isEmpty() && !suffix.isEmpty())
+        fname = QFileInfo(finfo.dir(), finfo.completeBaseName() 
                           + "." + suffix).filePath();
       d->ui.fileNameEdit->setText(fname);
     }
@@ -1659,8 +1661,8 @@ QDjViewPrintDialog::browse()
   if (! fname.isEmpty())
     {
       QFileInfo finfo(fname);
-      if (finfo.completeSuffix().isEmpty() && !suffix.isEmpty())
-        fname = QFileInfo(finfo.dir(), finfo.baseName() 
+      if (finfo.suffix().isEmpty() && !suffix.isEmpty())
+        fname = QFileInfo(finfo.dir(), finfo.completeBaseName() 
                           + "." + suffix).filePath();
       d->ui.fileNameEdit->setText(fname);
     }
