@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewplugin.cpp,v 1.54 2009/02/22 22:37:30 leonb Exp $
+// $Id: qdjviewplugin.cpp,v 1.56 2010/03/14 03:21:58 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -943,6 +943,9 @@ QDjViewPlugin::cmdAttachWindow()
       djview = new QDjView(*context, instance->viewerMode, shell);
       djview->setWindowFlags(djview->windowFlags() & ~Qt::Window);
       djview->setAttribute(Qt::WA_DeleteOnClose, false);
+#if QT_VERSION >= 0x40400
+      djview->setAttribute(Qt::WA_NativeWindow, true);
+#endif
       QLayout *layout = new QHBoxLayout(shell);
       layout->setMargin(0);
       layout->setSpacing(0);
@@ -1198,7 +1201,7 @@ QDjViewPlugin::cmdSetDjVuOpt()
   // print error messages
   if (errors.size() > 0)
     foreach(QString error, errors)
-      qWarning((const char*)error.toLocal8Bit());
+      qWarning("djvuopt: %s",(const char*)error.toLocal8Bit());
 }
 
 
