@@ -15,7 +15,7 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewsidebar.cpp,v 1.61 2009/04/06 11:15:07 leonb Exp $
+// $Id: qdjviewsidebar.cpp,v 1.63 2010/01/31 00:46:39 leonb Exp $
 
 #if AUTOCONF
 # include "config.h"
@@ -144,7 +144,7 @@ QDjViewOutline::refresh()
               miniexp_car(outline) != miniexp_symbol("bookmarks"))
             {
               QString msg = tr("Outline data is corrupted");
-              qWarning((const char*)msg.toLocal8Bit());
+              qWarning("%s", (const char*)msg.toLocal8Bit());
             }
           tree->clear();
           QTreeWidgetItem *root = new QTreeWidgetItem();
@@ -163,7 +163,7 @@ QDjViewOutline::refresh()
           tree->clear();
           QTreeWidgetItem *root = new QTreeWidgetItem(tree);
           root->setText(0, tr("Pages"));
-          root->setFlags(0);
+          root->setFlags(Qt::ItemIsEnabled);
           root->setData(0, Qt::UserRole, -1);
           for (int pageno=0; pageno<djview->pageNum(); pageno++)
             {
